| Title: | Import Stata 'webuse' Datasets |
|---|---|
| Description: | A Stata-style `webuse()` function for importing named datasets from Stata's online collection. |
| Authors: | Thomas J. Leeper [aut] (ORCID: <https://orcid.org/0000-0003-4097-6326>), Jodi Beggs [cre, aut] |
| Maintainer: | Jodi Beggs <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.3 |
| Built: | 2026-05-16 05:39:05 UTC |
| Source: | https://github.com/leeper/webuse |
Import Stata ‘webuse’ Datasets
webuse(data, version = 15, envir = parent.frame()) webuselistwebuse(data, version = 15, envir = parent.frame()) webuselist
data |
A character string containing the name of a Stata dataset. |
version |
An integer indicating the version of Stata for which to retrieve the named dataset. Default is version 14 (current as of June, 2015). |
envir |
An environment in which to store the object. By default, this will be the parent environment (often the global environment). |
webuse retrieves a named Stata dataset from Stata's server and loads it as a named object in the specified environment.
webuselist provides a named list of (some of) the datasets available. Use names(webuselist) to retrieve the datasets.
A data.frame, invisibly.
Thomas J. Leeper
webuse("auto") "auto" webuse("uslifeexp") "uslifeexp"webuse("auto") "auto" webuse("uslifeexp") "uslifeexp"