Welcome to ClientVPS Mirrors

Help for package webuse
Version: 0.1.3
Date: 2018-09-30
Title: Import Stata 'webuse' Datasets
Description: A Stata-style ‘webuse()' function for importing named datasets from Stata’s online collection.
Imports: haven
Suggests: testthat
License: MIT + file LICENSE
URL: https://github.com/leeper/webuse
BugReports: https://github.com/leeper/webuse/issues
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2018-09-30 23:23:10 UTC; jodinb
Author: Thomas J. Leeper ORCID iD [aut], Jodi Beggs [cre, aut]
Maintainer: Jodi Beggs <jodi@alum.mit.edu>
Repository: CRAN
Date/Publication: 2018-10-01 20:50:03 UTC

webuse

Description

Import Stata ‘webuse’ Datasets

Usage

    webuse(data, version = 15, envir = parent.frame())
    
    webuselist

Arguments

data

A character string containing the name of a Stata dataset.

version

An integer indicating the version of Stata for which to retrieve the named dataset. Default is version 14 (current as of June, 2015).

envir

An environment in which to store the object. By default, this will be the parent environment (often the global environment).

Details

webuse retrieves a named Stata dataset from Stata's server and loads it as a named object in the specified environment.

webuselist provides a named list of (some of) the datasets available. Use names(webuselist) to retrieve the datasets.

Value

A data.frame, invisibly.

Author(s)

Thomas J. Leeper

References

Stata webuse manual

Examples

webuse("auto")
"auto" 

webuse("uslifeexp")
"uslifeexp" 

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.